@@ -54,6 +54,9 @@ class __EXPORT AudioDevice;
  */
 class __EXPORT Audio
 {
+private:
+    __DELETE_COPY(Audio);
+
 public:
     typedef int16_t snd16_t;
     typedef int32_t snd32_t;
@@ -252,12 +255,16 @@ public:
         char *annotation;
 
         Info();
+        Info(const Info& copy);
+
         void clear(void);
         void set(void);
         void setFraming(timeout_t frame);
         void setRate(Rate rate);
     };
 
+    inline Audio() {}
+
     /**
      * Convert dbm power level to integer value (0-32768).
      *
@@ -645,6 +652,9 @@ public:
  */
 class __EXPORT AudioResample : public Audio
 {
+private:
+    __DELETE_DEFAULTS(AudioResample);
+
 protected:
     unsigned mfact, dfact, max;
     unsigned gpos, ppos;
@@ -669,6 +679,9 @@ public:
  */
 class __EXPORT AudioTone : public Audio
 {
+private:
+    __DELETE_COPY(AudioTone);
+
 protected:
     Rate rate;
     unsigned samples;
@@ -803,6 +816,9 @@ public:
  */
 class __EXPORT AudioBase : public Audio
 {
+private:
+    __DELETE_COPY(AudioBase);
+
 protected:
     Info info;
 
@@ -896,6 +912,9 @@ public:
  */
 class __EXPORT AudioBuffer : public AudioBase
 {
+private:
+    __DELETE_DEFAULTS(AudioBuffer);
+
 public:
     AudioBuffer(Info *info, size_t size = 4096);
     virtual ~AudioBuffer();
@@ -934,6 +953,9 @@ private:
  */
 class __EXPORT AudioFile: public AudioBase
 {
+private:
+    __DELETE_COPY(AudioFile);
+
 protected:
     char *pathname;
     Error error;
@@ -1395,6 +1417,9 @@ public:
  */
 class __EXPORT AudioStream : public AudioFile
 {
+private:
+    __DELETE_COPY(AudioStream);
+
 protected:
     AudioCodec *codec;  // if needed
     Encoded framebuf;
@@ -1619,6 +1644,9 @@ public:
  */
 class __EXPORT AudioCodec : public Audio, public LinkedObject
 {
+private:
+    __DELETE_COPY(AudioCodec);
+
 protected:
     Encoding encoding;
     const char *name;
@@ -1799,10 +1827,15 @@ public:
 
 class __EXPORT AudioDevice : public AudioBase
 {
+private:
+    __DELETE_COPY(AudioDevice);
+
 protected:
     bool enabled;
 
 public:
+    inline AudioDevice() {}
+
     virtual ~AudioDevice() {}
 
     /**
@@ -1929,6 +1962,9 @@ public:
  */
 class __EXPORT TelTone : public AudioTone
 {
+private:
+    __DELETE_DEFAULTS(TelTone);
+
 public:
     typedef struct _tonedef {
         struct _tonedef *next;
@@ -1961,7 +1997,7 @@ public:
      *
      * @return pointer to samples generated.
      */
-    Linear getFrame(void);
+    Linear getFrame(void) __OVERRIDE;
 
     /**
      * Check if all audio frames for this tone has been created.
@@ -1969,7 +2005,7 @@ public:
      *
      * @return true if audio is complete.
      */
-    bool is_complete(void);
+    bool is_complete(void) __OVERRIDE;
 
 
     /**
@@ -2010,6 +2046,9 @@ protected:
  */
 class __EXPORT DTMFTones : public AudioTone
 {
+private:
+    __DELETE_DEFAULTS(DTMFTones);
+
 protected:
     unsigned remaining, dtmfframes;
     timeout_t frametime;
@@ -2030,8 +2069,8 @@ public:
 
     ~DTMFTones();
 
-    Linear getFrame(void);
-    bool is_complete(void);
+    Linear getFrame(void) __OVERRIDE;
+    bool is_complete(void) __OVERRIDE;
 };
 
 /**
@@ -2045,6 +2084,9 @@ public:
  */
 class __EXPORT MFTones : public AudioTone
 {
+private:
+    __DELETE_DEFAULTS(MFTones);
+
 protected:
     unsigned remaining, mfframes;
     timeout_t frametime;
@@ -2065,8 +2107,8 @@ public:
 
     ~MFTones();
 
-    Linear getFrame(void);
-    bool is_complete(void);
+    Linear getFrame(void) __OVERRIDE;
+    bool is_complete(void) __OVERRIDE;
 };
 
 
@@ -2076,6 +2118,9 @@ public:
  */
 class __EXPORT DTMFDetect : public Audio
 {
+private:
+    __DELETE_COPY(DTMFDetect);
+
 public:
     DTMFDetect();
     ~DTMFDetect();
