@@ -1,5 +1,6 @@
 // Copyright (C) 2000-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU ccAudio2.
 //
@@ -21,7 +22,7 @@
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 AudioBuffer::AudioBuffer(Info *i, size_t sz) :
 AudioBase(i)
@@ -107,6 +108,6 @@ ssize_t AudioBuffer::put(Encoded data, size_t amount)
     return (ssize_t)amount;
 }
 
-
+} // namespace ucommon
 
 
