@@ -1065,6 +1065,21 @@ Audio::Info::Info()
     clear();
 }
 
+Audio::Info::Info(const Info& copy)
+{
+    format = copy.format;
+    encoding = copy.encoding;
+    rate = copy.rate;
+    bitrate = copy.bitrate;
+    order = copy.order;
+    framesize = copy.framesize;
+    framecount = copy.framecount;
+    headersize = copy.headersize;
+    padding = copy.padding;
+    framing = copy.framing;
+    annotation = copy.annotation;
+}
+
 void Audio::Info::clear(void)
 {
     memset(this, 0, sizeof(Info));
