@@ -197,25 +197,33 @@ unsigned AudioCodec::getPacket(Encoded packet, Encoded data, unsigned bytes)
 
 // g711 codecs initialized in static linkage...
 
-static class __LOCAL g711u : public AudioCodec {
+static class __LOCAL g711u : public AudioCodec 
+{
 public:
     g711u();
 
-    unsigned encode(Linear buffer, void *source, unsigned lsamples);
-    unsigned decode(Linear buffer, void *dest, unsigned lsamples);
-    Level impulse(void *buffer, unsigned samples);
-    Level peak(void *buffer, unsigned samples);
+private:
+    __DELETE_COPY(g711u);
+
+    unsigned encode(Linear buffer, void *source, unsigned lsamples) __FINAL;
+    unsigned decode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
+    Level impulse(void *buffer, unsigned samples) __FINAL;
+    Level peak(void *buffer, unsigned samples) __FINAL;
 
 } g711u;
 
-static class __LOCAL g711a : public AudioCodec {
+static class __LOCAL g711a : public AudioCodec 
+{
 public:
     g711a();
 
-    unsigned encode(Linear buffer, void *source, unsigned lsamples);
-    unsigned decode(Linear buffer, void *dest, unsigned lsamples);
-    Level impulse(void *buffer, unsigned samples);
-    Level peak(void *buffer, unsigned samples);
+private:
+    __DELETE_COPY(g711a);
+
+    unsigned encode(Linear buffer, void *source, unsigned lsamples) __FINAL;
+    unsigned decode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
+    Level impulse(void *buffer, unsigned samples) __FINAL;
+    Level peak(void *buffer, unsigned samples) __FINAL;
 
 } g711a;
 
@@ -314,9 +322,9 @@ unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
         7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
         7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7};
 
-    register Sample sample;
+    Sample sample;
     int sign, exponent, mantissa, retval;
-    register unsigned char *d = (unsigned char *)dest;
+    unsigned char *d = (unsigned char *)dest;
     unsigned count;
 
     count = lsamples;
@@ -338,7 +346,7 @@ unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
 
 unsigned g711u::decode(Linear buffer, void *source, unsigned lsamples)
 {
-    register unsigned char *src = (unsigned char *)source;
+    unsigned char *src = (unsigned char *)source;
     unsigned count;
 
     count = lsamples;
@@ -474,7 +482,7 @@ Audio::Level g711a::peak(void *data, unsigned samples)
 
 unsigned g711a::decode(Linear buffer, void *source, unsigned lsamples)
 {
-    register unsigned char *src = (unsigned char *)source;
+    unsigned char *src = (unsigned char *)source;
     unsigned count;
 
     static Sample values[256] =
@@ -872,6 +880,8 @@ static int step_size(
 static class __LOCAL g721Codec : private AudioCodec
 {
 private:
+    __DELETE_COPY(g721Codec);
+
     static short    _dqlntab[16];
     static short    _witab[16];
     static short    _fitab[16];
@@ -879,11 +889,11 @@ private:
 
     state_t encode_state, decode_state;
 
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    AudioCodec *getByInfo(Info &info) __FINAL;
+    AudioCodec *getByFormat(const char *format) __FINAL;
 
-    unsigned decode(Linear buffer, void *from, unsigned lsamples);
-    unsigned encode(Linear buffer, void *dest, unsigned lsamples);
+    unsigned decode(Linear buffer, void *from, unsigned lsamples) __FINAL;
+    unsigned encode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
     short coder(state_t *state, int nib);
     unsigned char encoder(short sl, state_t *state);
 
@@ -896,6 +906,8 @@ public:
 static class __LOCAL g723_3Codec : private AudioCodec
 {
 private:
+    __DELETE_COPY(g723_3Codec);
+
     static short    _dqlntab[8];
     static short    _witab[8];
     static short    _fitab[8];
@@ -903,11 +915,11 @@ private:
 
     state_t encode_state, decode_state;
 
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    AudioCodec *getByInfo(Info &info) __FINAL;
+    AudioCodec *getByFormat(const char *format) __FINAL;
 
-    unsigned decode(Linear buffer, void *from, unsigned lsamples);
-    unsigned encode(Linear buffer, void *dest, unsigned lsamples);
+    unsigned decode(Linear buffer, void *from, unsigned lsamples) __FINAL;
+    unsigned encode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
     short coder(state_t *state, int nib);
     unsigned char encoder(short sl, state_t *state);
 
@@ -920,6 +932,8 @@ public:
 static class __LOCAL g723_5Codec : private AudioCodec
 {
 private:
+    __DELETE_COPY(g723_5Codec);
+
     static short    _dqlntab[32];
     static short    _witab[32];
     static short    _fitab[32];
@@ -927,11 +941,11 @@ private:
 
     state_t encode_state, decode_state;
 
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    AudioCodec *getByInfo(Info &info)  __FINAL;
+    AudioCodec *getByFormat(const char *format)  __FINAL;
 
-    unsigned decode(Linear buffer, void *from, unsigned lsamples);
-    unsigned encode(Linear buffer, void *dest, unsigned lsamples);
+    unsigned decode(Linear buffer, void *from, unsigned lsamples) __FINAL;
+    unsigned encode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
     short coder(state_t *state, int nib);
     unsigned char encoder(short sl, state_t *state);
 
@@ -944,6 +958,8 @@ public:
 class __LOCAL g723_2Codec : public AudioCodec
 {
 private:
+    __DELETE_COPY(g723_2Codec);
+
     static short    _dqlntab[4];
     static short    _witab[4];
     static short    _fitab[4];
@@ -951,15 +967,15 @@ private:
 
     state_t encode_state, decode_state;
 
-public:
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    AudioCodec *getByInfo(Info &info) __FINAL;
+    AudioCodec *getByFormat(const char *format) __FINAL;
 
-    unsigned decode(Linear buffer, void *from, unsigned lsamples);
-    unsigned encode(Linear buffer, void *dest, unsigned lsamples);
+    unsigned decode(Linear buffer, void *from, unsigned lsamples) __FINAL;
+    unsigned encode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
     short coder(state_t *state, int nib);
     unsigned char encoder(short sl, state_t *state);
 
+public:
     g723_2Codec(const char *id, Encoding e);
     g723_2Codec();
     ~g723_2Codec();
@@ -1567,6 +1583,8 @@ static int oki_steps[49] = {
 static class __LOCAL okiCodec : private AudioCodec
 {
 private:
+    __DELETE_COPY(okiCodec);
+
     typedef struct state {
         short last;
         short ssindex;
@@ -1574,11 +1592,11 @@ private:
 
     state_t encode_state, decode_state;
 
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    AudioCodec *getByInfo(Info &info) __FINAL;
+    AudioCodec *getByFormat(const char *format) __FINAL;
 
-    unsigned decode(Linear buffer, void *from, unsigned lsamples);
-    unsigned encode(Linear buffer, void *dest, unsigned lsamples);
+    unsigned decode(Linear buffer, void *from, unsigned lsamples) __FINAL;
+    unsigned encode(Linear buffer, void *dest, unsigned lsamples) __FINAL;
     unsigned char encode_sample(state_t *state, short sample);
     short decode_sample(state_t *state, unsigned char code);
 
@@ -1737,12 +1755,14 @@ AudioCodec *okiCodec::getByFormat(const char *format)
 static class __LOCAL GSMCodec : private AudioCodec
 {
 private:
-    gsm encoder, decoder;
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    __DELETE_COPY(GSMCodec);
 
-    unsigned encode(Linear data, void *dest, unsigned samples);
-    unsigned decode(Linear data, void *source, unsigned samples);
+    gsm encoder, decoder;
+    AudioCodec *getByInfo(Info &info) __FINAL;
+    AudioCodec *getByFormat(const char *format) __FINAL;
+
+    unsigned encode(Linear data, void *dest, unsigned samples) __FINAL;
+    unsigned decode(Linear data, void *source, unsigned samples) __FINAL;
 
 public:
     GSMCodec(const char *id, Encoding e);
@@ -1840,21 +1860,28 @@ public:
     SpeexCommon();
     ~SpeexCommon();
 
-    unsigned encode(Linear buffer, void *dest, unsigned lsamples);
-    unsigned decode(Linear buffer, void *source, unsigned lsamples);
+protected:
+    unsigned encode(Linear buffer, void *dest, unsigned lsamples) __OVERRIDE;
+    unsigned decode(Linear buffer, void *source, unsigned lsamples) __OVERRIDE;
 
-    AudioCodec *getByInfo(Info &info);
-    AudioCodec *getByFormat(const char *format);
+    AudioCodec *getByInfo(Info &info) __OVERRIDE;
+    AudioCodec *getByFormat(const char *format) __OVERRIDE;
 } speex_codec(Audio::speexVoice, "speex");
 
 class __LOCAL SpeexAudio: public SpeexCommon
 {
+private:
+    __DELETE_COPY(SpeexAudio);
+
 public:
     SpeexAudio();
 };
 
 class __LOCAL SpeexVoice: public SpeexCommon
 {
+private:
+    __DELETE_COPY(SpeexVoice);
+
 public:
     SpeexVoice();
 };
