@@ -209,7 +209,7 @@ Audio::Error AudioFile::setPosition(unsigned long samples)
     if(samples == (unsigned long)~0l)
         return errSuccess;
 
-    pos = header + toBytes(info, samples);
+    pos = (long)(header + toBytes(info, samples));
     if(pos > eof) {
         pos = eof;
         return errSuccess;
