@@ -257,7 +257,7 @@ skip:
         while(i--) {
             snprintf(namebuf, sizeof(namebuf), "%s.%s",
                 *(field++), name);
-            tk = (tonekey_t *)map((unsigned)sizeof(tonekey_t) + strlen(namebuf));
+            tk = (tonekey_t *)map((unsigned)(sizeof(tonekey_t) + strlen(namebuf)));
             strcpy(tk->id, namebuf);
             tk->first = first;
             tk->last = final;
