@@ -54,16 +54,18 @@ private:
     Linear sendbuf;
     unsigned sendpos, bufsize;
 
+    __DELETE_COPY(OSSAudioDevice);
+
 public:
     OSSAudioDevice(int fdsp, int fmixer, DeviceMode mode);
     ~OSSAudioDevice();
 
-    bool setAudio(Rate rate, bool stereo, timeout_t timeout);
+    bool setAudio(Rate rate, bool stereo, timeout_t timeout) __FINAL;
 
-    unsigned putSamples(Linear buffer, unsigned count);
-    unsigned getSamples(Linear buffer, unsigned count);
+    unsigned putSamples(Linear buffer, unsigned count) __FINAL;
+    unsigned getSamples(Linear buffer, unsigned count) __FINAL;
 
-    void flush(void);
+    void flush(void) __FINAL;
     void resetPlay(void);
     void mutePlay(void);
     void resetRecord(void);
