@@ -132,9 +132,9 @@ char *AudioBuild::getContinuation(void)
 
 void AudioBuild::copyConvert(AudioStream &input, AudioStream &output)
 {
-    unsigned long samples, copied;
+    size_t samples, copied;
     Linear buffer, source;
-    unsigned pages, npages;
+    size_t pages, npages;
     Info from, to;
     bool mono = true;
     AudioResample *resampler = NULL;
@@ -178,9 +178,9 @@ void AudioBuild::copyConvert(AudioStream &input, AudioStream &output)
             copied = samples;
 
         if(mono)
-            npages = output.bufMono(source, copied);
+            npages = output.bufMono(source, (unsigned)copied);
         else
-            npages = output.bufStereo(source, copied);
+            npages = output.bufStereo(source, (unsigned)copied);
 
         if(!npages)
             break;
